@@ -1,7 +1,7 @@
 package Module::Path::More;
 
-our $DATE = '2016-01-09'; # DATE
-our $VERSION = '0.30'; # VERSION
+our $DATE = '2016-08-03'; # DATE
+our $VERSION = '0.31'; # VERSION
 
 use 5.010001;
 use strict;
@@ -202,7 +202,7 @@ Module::Path::More - Get path to locally installed Perl module
 
 =head1 VERSION
 
-This document describes version 0.30 of Module::Path::More (from Perl distribution Module-Path-More), released on 2016-01-09.
+This document describes version 0.31 of Module::Path::More (from Perl distribution Module-Path-More), released on 2016-08-03.
 
 =head1 SYNOPSIS
 
@@ -216,7 +216,7 @@ This document describes version 0.30 of Module::Path::More (from Perl distributi
  }
 
  # find all found modules, as well as .pmc and .pod files
- @path = module_path(module=>'Foo::Bar', all=>1, find_pmc=>1, find_pod=>1);
+ $paths = module_path(module=>'Foo::Bar', all=>1, find_pmc=>1, find_pod=>1);
 
  # just a shortcut for module_path(module=>'Foo',
  #                                 find_pm=>0, find_pmc=>0, find_pod=>1);
@@ -339,6 +339,22 @@ Module name to search.
 
 Return value:  (str|array[str])
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Module-Path-More>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/perlancar/perl-Module-Path-More>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Module-Path-More>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 SEE ALSO
 
 L<Module::Path>. Module::Path::More is actually a fork of Module::Path.
@@ -372,22 +388,6 @@ References:
 
 =back
 
-=head1 HOMEPAGE
-
-Please visit the project's homepage at L<https://metacpan.org/release/Module-Path-More>.
-
-=head1 SOURCE
-
-Source repository is at L<https://github.com/perlancar/perl-Alt-Module-Path-SHARYANTO>.
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Module-Path-More>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
